@@ -461,4 +461,4 @@ def process_question(input_file, output_path):
     pl_path =  output_path / "clientFilesQuestion"
     pl_path.parent.mkdir(parents=True, exist_ok=True)
     if files_to_copy:
-        [copy2(pathlib.Path(source_filepath).parent / fl, pl_path) for fl in files_to_copy]
\ No newline at end of file
+        [copy2(input_file.parent / fl, pl_path) for fl in files_to_copy]
\ No newline at end of file
